==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Alapvető információk</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Hozzáadás az albumhoz</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Összes kép</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Kép megnyitása</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eltávolítás az albumból</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nincs engedélye a kép megtekintéséhez</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Módosítás dátuma</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Fájlméret</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Rögzítés dátuma</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exponálási mód</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exponálási program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exponálási idő</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Vaku</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Nyílás</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fókusztávolság</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximum nyílás</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mérésmód</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Fehér egyensúly</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Vaku kompenzáció</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lencse modell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Színtér</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kamera modell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Méretek</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Címke</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 méret</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ablakhoz igazítás</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Szöveg kivonat</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Kilépés a teljes képernyős módból</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigációs ablak megjelenítése</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigációs ablak elrejtése</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>day</source>
        <translation>nap</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Írjon be egy új nevet</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nem találhatók képfájlok</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>A képfájl nem található</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Nincs engedélye a fájl megtekintéséhez</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.14.orig.tar.xz: image-editor-1.0.14/libimageviewer/translations/libimageviewer_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Alapvető információk</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Hozzáadás az albumhoz</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Összes kép</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Kép megnyitása</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eltávolítás az albumból</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nincs engedélye a kép megtekintéséhez</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Módosítás dátuma</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Fájlméret</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Rögzítés dátuma</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exponálási mód</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exponálási program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exponálási idő</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Vaku</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Nyílás</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fókusztávolság</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximum nyílás</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mérésmód</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Fehér egyensúly</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Vaku kompenzáció</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lencse modell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Színtér</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kamera modell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Méretek</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Címke</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 méret</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ablakhoz igazítás</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Szöveg kivonat</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás az óramutató járásával megegyezően</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Kilépés a teljes képernyős módból</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigációs ablak megjelenítése</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigációs ablak elrejtése</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképként</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>day</source>
        <translation>nap</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Fénykép információi</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Írjon be egy új nevet</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nem találhatók képfájlok</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>A képfájl nem található</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Nincs engedélye a fájl megtekintéséhez</translation>
    </message>
</context>
</TS>
